//
//  SpeakEasyAppDelegate.m
//  SpeakEasy
//
//  Created by Holger Hinzberg on 30.03.11.
//  Copyright 2011 Cocoa-Coding. All rights reserved.
//

#import "SpeakEasyAppDelegate.h"

@implementation SpeakEasyAppDelegate

@synthesize window;

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    // Den Sprachsynthesizer instanzieren
    speechSynth = [NSSpeechSynthesizer new];
    
    // Der Controller wird zum Delegate des 
    // NSSpeechSynthesizer
    [speechSynth setDelegate:self];
    
    // Button aktivieren/deaktivieren
    [stopButton setEnabled:FALSE];
    [sayButton setEnabled:TRUE];
    
    
    // Alle Stimmen des Sprachsynthesizers holen
    NSArray *voices =
    [NSSpeechSynthesizer availableVoices];
    
    // Alle eventuelle vorhandenen Einträge löschen
    [voicesPopUpButton removeAllItems];
    
    for (int i = 0; i < [voices count] - 1 ; i++)
    {
        // Immer ein Objekt aus dem Array
        NSString * voiceIdentifier;
        voiceIdentifier = [voices objectAtIndex:i];
        
        // Den Namen (voiceName) eines 
        // voiceIdentifier ermitteln.
        NSString *voiceName =
        [[NSSpeechSynthesizer attributesForVoice:
          voiceIdentifier] valueForKey:NSVoiceName];
        
        // Den voiceIdentifiert dem NSPopUpButton inzufügen 
        [voicesPopUpButton addItemWithTitle:voiceName];
    }
    
    int voiceIndex = 0;
    
    // Den ersten Eintrag im NSPopUpButton auswählen
    [voicesPopUpButton selectItemAtIndex:voiceIndex];
    
    // Die Stimme an der gleichen Indexposition auswählen
    [speechSynth setVoice:
     [[NSSpeechSynthesizer availableVoices]
      objectAtIndex:voiceIndex]];

}

- (IBAction)clickSayButton:(id)sender 
{
    // Die Zustände der Button umkehren
    [stopButton setEnabled:TRUE];
    [sayButton setEnabled:FALSE];
        
    // Den Text aus dem Textfeld in eine Variable holen
    NSString *input = [inputText stringValue];
    // Den Text an den Sprachsynthesizer senden
    [speechSynth startSpeakingString:input];
}

- (IBAction)clickStopButton:(id)sender
{
    // Abbruch der Sprachausgabe
    [speechSynth stopSpeaking];
}

- (IBAction)voiceSelected:(id)sender
{
    // Die gewählte Position ermitteln.
    NSInteger index = [voicesPopUpButton indexOfSelectedItem];
    
    // Die Stimme an der Indexposition auswählen
    [speechSynth setVoice:
     [[NSSpeechSynthesizer availableVoices]
      objectAtIndex:index]];
}

-(void)speechSynthesizer:
(NSSpeechSynthesizer *)sender 
       didFinishSpeaking:(BOOL)finishedSpeaking
{
    // Die Sprachausgabe wurde beendet.
    [stopButton setEnabled:FALSE];
    [sayButton setEnabled:TRUE];
}

-(BOOL)applicationShouldTerminateAfterLastWindowClosed:
(NSApplication *)sender
{
    return TRUE;
}

- (void)dealloc 
{
    [window release];
    [speechSynth release];
    [super dealloc];
}

@end
